@@ -1,6 +1,6 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2000-2001, 2007, 2009-2011 Free Software Foundation, Inc.
+    Copyright (C) 2000-2001, 2007, 2009-2012 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -449,7 +449,7 @@ ped_constraint_solve_max (const PedConstraint* constraint)
 	if (!constraint)
 		return NULL;
 	dev = constraint->start_range->dev;
-	ped_geometry_init (&full_dev, dev, 0, dev->length - 1);
+	ped_geometry_init (&full_dev, dev, 0, dev->length);
 	return ped_constraint_solve_nearest (constraint, &full_dev);
 }
 
