@@ -1,6 +1,6 @@
 /*
     apfs.c -- parted support for apfs file systems
-    Copyright (C) 1998-2000, 2007, 2009-2011 Free Software Foundation, Inc.
+    Copyright (C) 1998-2000, 2007, 2009-2012 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -108,29 +108,9 @@ _apfs2_probe (PedGeometry* geom) {
 
 static PedFileSystemOps _apfs1_ops = {
 	probe:		_apfs1_probe,
-	clobber:	NULL,
-	open:		NULL,
-	create:         NULL,
-	close:		NULL,
-	check:          NULL,
-	resize:		NULL,
-	copy:           NULL,
-	get_create_constraint:	NULL,
-	get_copy_constraint:	NULL,
-	get_resize_constraint:	NULL
 };
 static PedFileSystemOps _apfs2_ops = {
 	probe:		_apfs2_probe,
-	clobber:	NULL,
-	open:		NULL,
-	create:         NULL,
-	close:		NULL,
-	check:          NULL,
-	resize:		NULL,
-	copy:           NULL,
-	get_create_constraint:	NULL,
-	get_copy_constraint:	NULL,
-	get_resize_constraint:	NULL
 };
 
 #define APFS_BLOCK_SIZES ((int[2]){512, 0})
