@@ -698,15 +698,16 @@ fdasd_valid_vtoc_pointer(fdasd_anchor_t *anc, unsigned long b, int fd)
 	/* VOL1 label contains valid VTOC pointer */
 	vtoc_read_label (fd, b, NULL, anc->f4, NULL, NULL);
 
-	if (anc->f4->DS4IDFMT != 0xf4) {
-		if (strncmp(anc->vlabel->volkey,vtoc_ebcdic_enc("LNX1",str,4),4) == 0)
-			return 0;
-		fdasd_error(anc, wrong_disk_format, _("Invalid VTOC."));
-	} else {
+	if (anc->f4->DS4IDFMT == 0xf4) {
 		fdasd_process_valid_vtoc (anc, b, fd);
+		return 0;
 	}
+	if (strncmp(anc->vlabel->volkey, vtoc_ebcdic_enc("LNX1",str,4),4) == 0 ||
+	    strncmp(anc->vlabel->volkey, vtoc_ebcdic_enc("CMS1",str,4),4) == 0)
+		return 0;
 
-	return 0;
+	fdasd_error(anc, wrong_disk_format, _("Invalid VTOC."));
+	return 1;
 }
 
 /*
@@ -737,7 +738,8 @@ fdasd_check_volume (fdasd_anchor_t *anc, int fd)
 		} else {
 			return 1;
 		}
-	} else if (strncmp (v->volkey, vtoc_ebcdic_enc ("LNX1", str, 4), 4) == 0) {
+	} else if (strncmp (v->volkey, vtoc_ebcdic_enc ("LNX1", str, 4), 4) == 0 ||
+	           strncmp (v->volkey, vtoc_ebcdic_enc ("CMS1", str, 4), 4) == 0) {
 		return 0;
 	}
 
@@ -752,7 +754,7 @@ fdasd_check_api_version (fdasd_anchor_t *anc, int f)
 {
 	PDEBUG
 	int api;
-	char s[LINE_LENGTH];
+	char s[2*LINE_LENGTH];
 
         struct stat st;
         if (fstat (f, &st) == 0 && S_ISREG (st.st_mode)) {
@@ -813,11 +815,6 @@ fdasd_get_geometry (const PedDevice *dev, fdasd_anchor_t *anc, int f)
 				    _("Could not retrieve disk information."));
 	}
 
-	if (strncmp(dasd_info.type, "ECKD", 4) != 0)
-		fdasd_error(anc, wrong_disk_type,
-			    _("This is not an ECKD disk!  " \
-			      "This disk type is not supported!"));
-
 	anc->dev_type   = dasd_info.dev_type;
 	anc->blksize    = blksize;
 	anc->label_pos  = dasd_info.label_block * blksize;
