@@ -1,6 +1,6 @@
 /*
     libparted - a library for manipulating disk partitions
-    Copyright (C) 2000, 2002, 2004, 2007-2011 Free Software Foundation, Inc.
+    Copyright (C) 2000, 2002, 2004, 2007-2012 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -406,7 +406,7 @@ _rawpart_is_driver (const MacRawPartition* raw_part)
 	return 1;
 }
 
-static int
+static int _GL_ATTRIBUTE_PURE
 _rawpart_has_driver (const MacRawPartition* raw_part, MacDiskData* mac_disk_data)
 {
 	MacDeviceDriver *driverlist;
@@ -704,8 +704,7 @@ _disk_analyse_ghost_size (PedDisk* disk)
 		if (_rawpart_check_signature (buf)
 		    && !_rawpart_is_void (buf)) {
 			mac_disk_data->ghost_size = i;
-			PED_ASSERT (i <= disk->dev->sector_size / 512);
-			found = 1;
+			found = (i <= disk->dev->sector_size / 512);
 			break;
 		}
 	}
@@ -728,7 +727,6 @@ mac_read (PedDisk* disk)
 	PedPartition*		part;
 	int			num;
 	PedSector		ghost_size;
-	PedConstraint*		constraint_exact;
 	int			last_part_entry_num = 0;
 
 	PED_ASSERT (disk != NULL);
@@ -795,10 +793,14 @@ mac_read (PedDisk* disk)
 			goto error_delete_all;
 		part->num = num;
 		part->fs_type = ped_file_system_probe (&part->geom);
-		constraint_exact = ped_constraint_exact (&part->geom);
-		if (!ped_disk_add_partition (disk, part, constraint_exact))
+		PedConstraint *constraint_exact
+			= ped_constraint_exact (&part->geom);
+		if (constraint_exact == NULL)
 			goto error_delete_all;
+		bool ok = ped_disk_add_partition (disk, part, constraint_exact);
 		ped_constraint_destroy (constraint_exact);
+		if (!ok)
+			goto error_delete_all;
 
 		if (_rawpart_is_partition_map (raw_part)) {
 			if (mac_disk_data->part_map_entry_num
@@ -1011,7 +1013,7 @@ _generate_empty_part (PedDisk* disk, int num, MacRawPartition* part_map)
 }
 
 /* returns the first empty entry in the partition map */
-static int
+static int _GL_ATTRIBUTE_PURE
 _get_first_empty_part_entry (PedDisk* disk, MacRawPartition* part_map)
 {
 	MacDiskData*	mac_disk_data = disk->disk_specific;
@@ -1289,7 +1291,7 @@ mac_partition_set_flag (PedPartition* part, PedPartitionFlag flag, int state)
 	}
 }
 
-static int
+static int _GL_ATTRIBUTE_PURE
 mac_partition_get_flag (const PedPartition* part, PedPartitionFlag flag)
 {
 	MacPartitionData*	mac_data;
@@ -1366,7 +1368,7 @@ mac_partition_set_name (PedPartition* part, const char* name)
 		mac_data->volume_name [i] = 0;
 }
 
-static const char*
+static const char* _GL_ATTRIBUTE_PURE
 mac_partition_get_name (const PedPartition* part)
 {
 	MacPartitionData*	mac_data;
