@@ -1,7 +1,7 @@
 #!/bin/sh
 # enforce limits on partition start sector and length
 
-# Copyright (C) 2008-2011 Free Software Foundation, Inc.
+# Copyright (C) 2008-2012 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -82,7 +82,7 @@ do_mkpart $n $end || fail=1
 parted -s $dev unit s p > out 2>&1 || fail=1
 sed -n "/^  *1  *$n/s/  */ /gp" out|sed "s/  *\$//" > k && mv k out || fail=1
 echo " 1 ${n}s ${end}s 4294967295s primary" > exp || fail=1
-compare out exp || fail=1
+compare exp out || fail=1
 
 # a partition length of exactly 2^32 sectors provokes failure.
 do_mkpart $n $(echo $n+2^32-1|bc) > err 2>&1
@@ -94,7 +94,7 @@ bad_part_length()
 
 # check for new diagnostic
 bad_part_length 4294967296 > exp || fail=1
-compare err exp || fail=1
+compare exp err || fail=1
 
 # FIXME: investigate this.
 # Unexpectedly to me, both of these failed with this same diagnostic:
@@ -113,7 +113,7 @@ test $? = 1 || fail=1
 
 # check for new diagnostic
 bad_part_length 4294967297 > exp || fail=1
-compare err exp || fail=1
+compare exp err || fail=1
 
 # =========================================================
 # Now consider partition starting sector numbers.
@@ -129,9 +129,10 @@ do_mkpart_start_and_len $(echo 2^32-1|bc) 1000 || fail=1
 # FIXME: In the long run, figure out if it's sensible.
 cat > exp <<EOF
 Model:  (file)
-Disk: 4294970342s
+Disk $dev: 4294970342s
 Sector size (logical/physical): ${ss}B/${ss}B
 Partition Table: $table_type
+Disk Flags:
 
 Number  Start        End          Size   Type      File system  Name  Flags
  9      0s           4095s        4096s  extended
@@ -141,8 +142,9 @@ EOF
 
 # print the result
 parted -s $dev unit s p > out 2>&1 || fail=1
-sed "s/Disk .*:/Disk:/;s/ *$//" out > k && mv k out || fail=1
-compare out exp || fail=1
+sed "s/^Disk .*\($dev: [0-9][0-9]*s\)$/Disk \1/;s/ *$//" out > k \
+    && mv k out || fail=1
+compare exp out || fail=1
 
 # a partition start sector number of 2^32 must fail
 do_mkpart_start_and_len $(echo 2^32|bc) 1000 > err 2>&1
@@ -150,7 +152,7 @@ test $? = 1 || fail=1
 
 # check for new diagnostic
 bad_start_sector 4294967296 > exp || fail=1
-compare err exp || fail=1
+compare exp err || fail=1
 
 # a partition start sector number of 2^32+1 must fail, too.
 do_mkpart_start_and_len $(echo 2^32+1|bc) 1000 > err 2>&1
@@ -158,7 +160,7 @@ test $? = 1 || fail=1
 
 # check for new diagnostic
 bad_start_sector 4294967297 > exp || fail=1
-compare err exp || fail=1
+compare exp err || fail=1
 
 done
 
