@@ -1,7 +1,7 @@
 #!/bin/sh
 # check physical sector size as reported by 'print'
 
-# Copyright (C) 2009-2011 Free Software Foundation, Inc.
+# Copyright (C) 2009-2012 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,6 +36,6 @@ parted -s $scsi_dev mklabel gpt print > out 2>&1 || fail=1
 grep '^Sector' out > k 2>&1 || fail=1
 mv k out || fail=1
 
-compare out exp || fail=1
+compare exp out || fail=1
 
 Exit $fail
